#!/bin/bash

# Installer script for qq2clone

#------------------------------------------------------------------------#
# Copyright 2021, Jesse Gardner                                          #
#------------------------------------------------------------------------#
# This file is part of qq2clone.                                         #
#                                                                        #
# qq2clone is free software: you can redistribute it and/or modify       #
# it under the terms of the GNU General Public License as published by   #
# the Free Software Foundation, either version 2 of the License, or      #
# (at your option) any later version.                                    #
#                                                                        #
# qq2clone is distributed in the hope that it will be useful,            #
# but WITHOUT ANY WARRANTY; without even the implied warranty of         #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          #
# GNU General Public License for more details.                           #
#                                                                        #
# You should have received a copy of the GNU General Public License      #
# along with qq2clone.  If not, see <https://www.gnu.org/licenses/>.     #
#------------------------------------------------------------------------#

# base64 encoded tgz archive will be added by gen_all.bash in archive below

archive='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=
'

[[ -z "$HOME" ]] &&
  { echo '$HOME must be defined'; exit 1; }

temp_dir="$(mktemp -d)" ||
  { echo "Failed to create temp directory"; exit 1; }
trap "rm -rf \"${temp_dir:?}\" &>/dev/null" EXIT

{
  cd "$temp_dir" &&
  echo "$archive" | base64 -d > archive.tgz &&
  tar -xzf archive.tgz &&
  rm archive.tgz
} || { echo "Problem unpacking data to $temp_dir"; exit 1; }

declare input="" location="${HOME}/storage-qq2clone"
while [[ ! "$input" =~ ^(y|n|Y|N)$ ]]; do
  echo "[y/n] Use default storage directory '$location' ?"
  read -rn1 input; echo
done

while [[ ! "$input" =~ (y|Y) ]]; do
  echo "Type in new location"
  read -r location; input=""
  while [[ ! "$input" =~ ^(y|n|Y|N)$ ]]; do
    echo "[y/n] Accept location '$location' ?"
    read -rn 1 input; echo
  done
done
echo

{
  mkdir -p "${HOME}/.config" &&
  echo "$location" > "${HOME}/.config/qq2clone"
} || { echo "Failed to write to ${HOME}/.config/qq2clone"; exit 1; }

{
  mkdir -p "$location" &&
  find -mindepth 1 -exec mv \{\} "$location"/\{\} \;
} || { echo "Cannot create/write to '$location'"; exit 1; }

if { command -v sudo &>/dev/null || [[ "$USER" == "root" ]]; }; then

  input=""
  qq_moved=0
  while : ; do
    while [[ ! "$input" =~ ^(y|n|Y|N)$ ]]; do
      echo "[y/n] Move main script file to /usr/bin/qq2clone ?"
      read -rn 1 input; echo
    done
    if [[ "$input" =~ ^(y|Y)$ ]]; then
      success=1
      if [[ "$USER" == "root" ]]; then
        mv "${location}/qq2clone" /usr/bin/qq2clone || success=0
      else
        sudo mv "${location}/qq2clone" /usr/bin/qq2clone || success=0
      fi
      ((success)) && { echo "File moved"; qq_moved=1; break; }
      echo "Attempt failed."; input=""; continue
    else
      echo "You have chosen to leave the main script file at:"
      echo "  ${location}/qq2clone"
      break
    fi
  done
  echo

  input=""
  while : ; do
    while [[ ! "$input" =~ ^(y|n|Y|N)$ ]]; do
      echo "[y/n] Move man page to /usr/local/man/man1/qq2clone.1 ?"
      read -rn 1 input; echo
    done
    if [[ "$input" =~ ^(y|Y)$ ]]; then
      success=1
      if [[ "$USER" == "root" ]]; then
        {
          mkdir -p /usr/local/man/man1 &&
          mv "${location}/qq2clone.1" /usr/local/man/man1/qq2clone.1
        } ||
          success=0
      else
        {
          sudo mkdir -p /usr/local/man/man1 &&
          sudo mv "${location}/qq2clone.1" /usr/local/man/man1/qq2clone.1
        } ||
          success=0
      fi
      ((success)) && { echo "File moved"; break; }
      echo "Attempt failed."; input=""; continue
    else
      echo "You have chosen to leave the man page at:"
      echo "  ${location}/qq2clone.1"
      break
    fi
  done

else
  echo "sudo is not installed on this system, so script and man page files"
  echo "will not be moved to /usr/bin/ and /usr/local/man"
  echo "  [Main script] ${location}/qq2clone"
  echo "  [Man page]    ${location}/qq2clone.1"
  echo "Manually move these files to desired location on this system"
fi
echo

input=""
while [[ ! "$input" =~ ^(y|n|Y|N)$ ]]; do
  echo "[y/n] qq2clone has a bash completion script. Modify ~/.bashrc to"
  echo "      source the completion script?"
  read -rn 1 input; echo
done

if [[ "$input" =~ ^(y|Y)$ ]]; then
  if echo "source ${location}/qq2clone_completion.bash" >> \
       "${HOME}/.bashrc"; then
    echo ".bashrc modified."
  else
    echo "Failed to write to ${HOME}/.bashrc . Completion script is"
    echo "available at:"
    echo "  ${location}/qq2clone_completion.bash"
  fi
else
  echo "Completion script is available at:"
  echo "  ${location}/qq2clone_completion.bash"
fi
echo

if ((qq_moved)); then
  /usr/bin/qq2clone setup
else
  "${location}/qq2clone" setup
fi
setup_code=$?

if ((setup_code != 0)); then
  echo "Setup failed. Resolve problem(s) described, then manually run"
  echo "the setup again using: qq2clone setup"
fi

exit $setup_code
